==> plugin-api-1.2.2-sources.jar: com/xebialabs/deployit/ci/mapping/SourcePropertyOverridingMapping.java <==
/*
 * Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to  (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.ci.mapping;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import com.xebialabs.deployit.ConfigurationItem;
import com.xebialabs.deployit.ConfigurationItemProperty;

/**
 * A mapping that has a list of key/value pairs that can override values of the source.
 */
@SuppressWarnings("serial")
@ConfigurationItem(description = "A mapping that has a list of key/value pairs that can override values of the source")
public abstract class SourcePropertyOverridingMapping extends Mapping {

	@ConfigurationItemProperty(description = "Overrides for properties of the mapping's source. The key is the property name (consult the documentation or run 'describe' in the CLI), the value is the value to set. Only string, integer and enumerable properties can be overridden. Example: Key: redeliveryLimits, Value: 2")
	private List<KeyValuePair> sourcePropertyOverrides = new ArrayList<KeyValuePair>();

	public SourcePropertyOverridingMapping() {
	}

	public SourcePropertyOverridingMapping(Serializable source, Serializable target) {
		super(source, target);
	}

	public List<KeyValuePair> getSourcePropertyOverrides() {
		return sourcePropertyOverrides;
	}

	public void setSourcePropertyOverrides(List<KeyValuePair> sourcePropertyOverrides) {
		this.sourcePropertyOverrides = sourcePropertyOverrides;
	}

	public void addSourcePropertyOverride(KeyValuePair sourcePropertyOverride) {
		if (sourcePropertyOverrides == null) {
			sourcePropertyOverrides = new ArrayList<KeyValuePair>();
		}
		sourcePropertyOverrides.add(sourcePropertyOverride);
	}
}

==> plugin-api-1.3.1-sources.jar: com/xebialabs/deployit/ci/mapping/SourcePropertyOverridingMapping.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.ci.mapping;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import com.xebialabs.deployit.ConfigurationItemProperty;

/**
 * A mapping that has a list of key/value pairs that can override values of the source.
 */
@SuppressWarnings("serial")
public abstract class SourcePropertyOverridingMapping<S extends Serializable, T extends Serializable> extends Mapping<S, T> {

	@ConfigurationItemProperty(description = "Overrides for properties of the mapping's source. The key is the property name (consult the documentation or run 'describe' in the CLI), the value is the value to set. Only string, integer and enumerable properties can be overridden. Example: Key: redeliveryLimits, Value: 2")
	private List<KeyValuePair> sourcePropertyOverrides = new ArrayList<KeyValuePair>();

	public SourcePropertyOverridingMapping() {
	}

	public SourcePropertyOverridingMapping(S source, T target) {
		super(source, target);
	}

	public List<KeyValuePair> getSourcePropertyOverrides() {
		return sourcePropertyOverrides;
	}

	public void setSourcePropertyOverrides(List<KeyValuePair> sourcePropertyOverrides) {
		this.sourcePropertyOverrides = sourcePropertyOverrides;
	}

	public void addSourcePropertyOverride(KeyValuePair sourcePropertyOverride) {
		if (sourcePropertyOverrides == null) {
			sourcePropertyOverrides = new ArrayList<KeyValuePair>();
		}
		sourcePropertyOverrides.add(sourcePropertyOverride);
	}
}
